==> open-cluster-management-apps-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ApplicationListFluent.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ApplicationListFluent<A extends ApplicationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Application item);
  public A setToItems(Integer index,Application item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Application... items);
  public A addAllToItems(Collection<Application> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Application... items);
  public A removeAllFromItems(Collection<Application> items);
  public A removeMatchingFromItems(Predicate<ApplicationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Application> getItems();
  public List<Application> buildItems();
  public Application buildItem(Integer index);
  public Application buildFirstItem();
  public Application buildLastItem();
  public Application buildMatchingItem(Predicate<ApplicationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ApplicationBuilder> predicate);
  public A withItems(List<Application> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Application... items);
  public Boolean hasItems();
  public ApplicationListFluent.ItemsNested<A> addNewItem();
  public ApplicationListFluent.ItemsNested<A> addNewItemLike(Application item);
  public ApplicationListFluent.ItemsNested<A> setNewItemLike(Integer index,Application item);
  public ApplicationListFluent.ItemsNested<A> editItem(Integer index);
  public ApplicationListFluent.ItemsNested<A> editFirstItem();
  public ApplicationListFluent.ItemsNested<A> editLastItem();
  public ApplicationListFluent.ItemsNested<A> editMatchingItem(Predicate<ApplicationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ApplicationFluent<ApplicationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ApplicationListFluent.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ApplicationListFluent<A extends ApplicationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Application item);
  public A setToItems(int index,Application item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Application... items);
  public A addAllToItems(Collection<Application> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Application... items);
  public A removeAllFromItems(Collection<Application> items);
  public A removeMatchingFromItems(Predicate<ApplicationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Application> getItems();
  public List<Application> buildItems();
  public Application buildItem(int index);
  public Application buildFirstItem();
  public Application buildLastItem();
  public Application buildMatchingItem(Predicate<ApplicationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ApplicationBuilder> predicate);
  public A withItems(List<Application> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Application... items);
  public Boolean hasItems();
  public ApplicationListFluent.ItemsNested<A> addNewItem();
  public ApplicationListFluent.ItemsNested<A> addNewItemLike(Application item);
  public ApplicationListFluent.ItemsNested<A> setNewItemLike(int index,Application item);
  public ApplicationListFluent.ItemsNested<A> editItem(int index);
  public ApplicationListFluent.ItemsNested<A> editFirstItem();
  public ApplicationListFluent.ItemsNested<A> editLastItem();
  public ApplicationListFluent.ItemsNested<A> editMatchingItem(Predicate<ApplicationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ApplicationFluent<ApplicationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
